@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from django.core.urlresolvers import reverse as django_reverse
+from django.contrib.staticfiles.storage import staticfiles_storage
 
 def url(name, *args, **kwargs):
     """
@@ -10,8 +11,12 @@ def url(name, *args, **kwargs):
     Usage example:
         {{ url('web:timeline', userid=2) }}
 
-    This is a equivalent to django: 
+    This is a equivalent to django:
         {% url 'web:timeline' userid=2 %}
 
     """
     return django_reverse(name, args=args, kwargs=kwargs)
+
+
+def static(path):
+    return staticfiles_storage.url(path)
